import { CustomResource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { CreateServiceLinkedRoleProps } from './create-service-linked-role-props';
import { ServiceLinkedRoleService } from './service-linked-role-service';
/**
 * Create service linked role for the indicated service if it doesn't exists
 *
 * @example
 * const slr = new dsf.utils.CreateServiceLinkedRole(this, 'CreateSLR')
 * slr.create(ServiceLinkedRoleService.REDSHIFT)
 */
export declare class CreateServiceLinkedRole extends Construct {
    private readonly serviceToken;
    private readonly providerRole;
    constructor(scope: Construct, id: string, props?: CreateServiceLinkedRoleProps);
    /**
       * Creates the service linked role associated to the provided AWS service
       * @param slrService See `ServiceLinkedRoleService` for supported service constant
       * @returns `CustomResource` that manages  the creation of the Service Linked Role
       */
    create(slrService: ServiceLinkedRoleService): CustomResource;
}
